@@ -1,6 +1,7 @@
 from org.maemo.hermes.engine.names import canonical
 from org.maemo.hermes.engine.friend import Friend
 import org.maemo.hermes.engine.service
+import urllib2
 
 class Service(org.maemo.hermes.engine.service.Service):
     """Twitter backend for Hermes.
@@ -117,5 +118,6 @@ class Service(org.maemo.hermes.engine.service.Service):
     def _register_match(self, contact, friend):
         friend.set_contact(contact)
         self._friends_by_contact[contact] = friend
-        self._friends.remove(friend)
+        if friend in self._friends:
+            self._friends.remove(friend)
 
